@@ -59,10 +59,10 @@ transf, atransf, targs, efac, col, border, lty, fonts, cex, ...) {
       mlab <- NULL
 
    if (missing(col))
-      col <- "black"
+      col <- par("fg")
 
    if (missing(border))
-      border <- "black"
+      border <- par("fg")
 
    if (missing(lty))
       lty <- "dotted"
