@@ -1,12 +1,13 @@
 weights.rma.peto <- function(object, type="diagonal", ...) {
 
-   if (!inherits(object, "rma.peto"))
-      stop("Argument 'object' must be an object of class \"rma.peto\".")
+   mstyle <- .get.mstyle("crayon" %in% .packages())
+
+   .chkclass(class(object), must="rma.peto")
 
    na.act <- getOption("na.action")
 
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
-      stop("Unknown 'na.action' specified under options().")
+      stop(mstyle$stop("Unknown 'na.action' specified under options()."))
 
    type <- match.arg(type, c("diagonal", "matrix"))
 
@@ -14,27 +15,27 @@ weights.rma.peto <- function(object, type="diagonal", ...) {
 
    #########################################################################
 
-   n1i <- x$ai + x$bi
-   n2i <- x$ci + x$di
-   Ni  <- x$ai + x$bi + x$ci + x$di
-   xt  <- x$ai + x$ci
-   yt  <- x$bi + x$di
+   n1i <- with(x$outdat, ai + bi)
+   n2i <- with(x$outdat, ci + di)
+   Ni  <- with(x$outdat, ai + bi + ci + di)
+   xt  <- with(x$outdat, ai + ci)
+   yt  <- with(x$outdat, bi + di)
 
-   wi  <- xt * yt * (n1i/Ni) * (n2i/Ni) / (Ni - 1)
+   wi <- xt * yt * (n1i/Ni) * (n2i/Ni) / (Ni - 1)
 
    #########################################################################
 
    if (type == "diagonal") {
 
       weight <- rep(NA_real_, x$k.f)
-      weight[x$not.na] <- wi/sum(wi) * 100
+      weight[x$not.na] <- wi / sum(wi) * 100
       names(weight) <- x$slab
 
       if (na.act == "na.omit")
          weight <- weight[x$not.na]
 
       if (na.act == "na.fail" && any(!x$not.na))
-         stop("Missing values in weights.")
+         stop(mstyle$stop("Missing values in weights."))
 
       return(weight)
 
@@ -52,7 +53,7 @@ weights.rma.peto <- function(object, type="diagonal", ...) {
          Wfull <- Wfull[x$not.na, x$not.na, drop=FALSE]
 
       if (na.act == "na.fail" && any(!x$not.na))
-         stop("Missing values in results.")
+         stop(mstyle$stop("Missing values in results."))
 
       return(Wfull)
 
