@@ -2,11 +2,10 @@
 
 context("Checking misc: head.list.rma() and tail.list.rma() functions")
 
-source("tolerances.r") # read in tolerances
+source("settings.r")
 
 test_that("head.list.rma() works correctly.", {
 
-   data(dat.bcg, package="metafor")
    dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
    res <- rma(yi, vi, data=dat)
    res <- head(rstandard(res), 4)
@@ -19,7 +18,6 @@ test_that("head.list.rma() works correctly.", {
 
 test_that("tail.list.rma() works correctly.", {
 
-   data(dat.bcg, package="metafor")
    dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
    res <- rma(yi, vi, data=dat)
    res <- tail(rstandard(res), 4)
@@ -32,7 +30,6 @@ test_that("tail.list.rma() works correctly.", {
 
 test_that("as.data.frame.list.rma() works correctly.", {
 
-   data(dat.bcg, package="metafor")
    dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
    res <- rma(yi, vi, mods = ~ ablat, data=dat)
    res <- predict(res)
@@ -47,7 +44,6 @@ test_that("as.data.frame.list.rma() works correctly.", {
 
 test_that("as.matrix.list.rma() works correctly.", {
 
-   data(dat.bcg, package="metafor")
    dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
    res <- rma(yi, vi, mods = ~ ablat, data=dat)
    res <- predict(res)
@@ -59,3 +55,5 @@ test_that("as.matrix.list.rma() works correctly.", {
    expect_equivalent(res, sav, tolerance=.tol[["misc"]])
 
 })
+
+rm(list=ls())
